@@ -14,10 +14,10 @@ from linghelper import DTW,getSemanticRelatedness
 from praatinterface import PraatLoader
 
 if 'phonostats' in settings.INSTALLED_APPS:
-    from phonostats import getNeighCount,getPhonotacticProb
+    from phonostats.utils import getNeighCount,getPhonotacticProb
 
 if 'celex' in settings.INSTALLED_APPS:
-    from celex import lookupStress,lookupCat
+    from celex.utils import lookupStress,lookupCat
 
 from .utils import fetch_buckeye_resource
 from .managers import BulkManager
